==> hoteldruid-mod-de_2.3.0-1.zip: de/messaggi.php <==
<?php

switch ($messaggio) {

case "Torna al menù principale":  		$messaggio = "Zur&uuml;ck zum Hauptmen&uuml;"; break;
case "Nuovo messaggio a":  			$messaggio = "Neue Mitteilung an"; break;
case "da mostrare dopo le":  			$messaggio = "Anzuzeigen ab"; break;
case "il":  					$messaggio = "den"; break;
case "testo del messaggio":  			$messaggio = "Mitteilungstext"; break;
case "Messaggi":  				$messaggio = "Mitteilungen"; break;
case "Spedisci":  				$messaggio = "Senden"; break;
case "Messaggio inviato":  			$messaggio = "Mitteilung versandt"; break;
case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
case "N°":  					$messaggio = "N"; break;
case "Mittente":  				$messaggio = "Absender"; break;
case "Data":  					$messaggio = "Datum"; break;
case "Azioni":  				$messaggio = "Aktionen"; break;
case "Elimina":  				$messaggio = "L&ouml;schen"; break;
case "Messaggio eliminato":  			$messaggio = "Mitteilung gel&ouml;scht"; break;
case "tutti":  					$messaggio = "jeden"; break;
case "SI":  					$messaggio = "JA"; break;
case "Si è sicuri di voler eliminare la richiesta di prenotazione di":	$messaggio = "Sind Sie sicher, dass Sie die Reservierungsanfrage l&ouml;schen wollen von"; break;
case "non ancora inserita?":  			$messaggio = "noch nicht eingef&uuml;gt?"; break;
case "Inserisci la prenotazione":  		$messaggio = "Reservierung einf&uuml;gen"; break;
case "Visualizza il documento":  		$messaggio = "Dokument anzeigen"; break;
case "di tipo":  				$messaggio = "Typ"; break;
case "Inserito":  				$messaggio = "Eingef&uuml;gt"; break;
case "Elimina tutti i messaggi":  		$messaggio = "Alle Nachrichten l&ouml;schen"; break;
case "Si è sicuri di voler eliminare <div style=\"display: inline; color: red;\"><b>tutti i messaggi</b></div>":                                                 $messaggio = "Sind Sie sicher, dass Sie <div style=\"display: inline; color: red;\"><b>alle Nachrichten l&ouml;schen</b></div> wollen?"; break;
case "Messaggi eliminati":  			$messaggio = "Mitteilungen gel&ouml;scht"; break;
case "arrivati":  				$messaggio = "angekommen"; break;
case "prima del":  				$messaggio = "vor"; break;
case "dopo il":  				$messaggio = "nach"; break;
case "Testo":  					$messaggio = "Text"; break;
case "Scarica messaggi email":  		$messaggio = "Download email messages"; break;
case "Nessun nuovo messaggio":  		$messaggio = "No new message"; break;
case "Nuovi messaggi":  			$messaggio = "New messages"; break;
case "Scaricati":  				$messaggio = "Downloaded"; break;
case "Connessione al server":  			$messaggio = "The connection to server"; break;
case "non riuscita!":  				$messaggio = "was refused!"; break;
case "Controllare i dati immessi in \"configura e personalizza\"":	$messaggio = "Check data inserted in \"configure and customize\""; break;
case "Dati ricavati dal messaggio email":  	$messaggio = "Data extracted from email message"; break;
case "Controlla disponibilità":  		$messaggio = "Check availability"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Email":  					$messaggio = "Email"; break;
case "arrivo":  				$messaggio = "arrival"; break;
case "partenza":  				$messaggio = "departure"; break;
case "notti":  					$messaggio = "nights"; break;
case "persone":  				$messaggio = "people"; break;
case "individui":  				$messaggio = "persons"; break;
case "ospiti":  				$messaggio = "guests"; break;
case "adulti":  				$messaggio = "adults"; break;
case "bambini":  				$messaggio = "children"; break;
case "gruppo":  				$messaggio = "party"; break;
case "date":  					$messaggio = "dates"; break;
case "viaggiatori":  				$messaggio = "travelers"; break;
case "periodo":  				$messaggio = "period"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-de_3.0.8-1.zip: de/messaggi.php <==
<?php

switch ($messaggio) {

case "Torna al menù principale":  		$messaggio = "Zur&uuml;ck zum Hauptmen&uuml;"; break;
case "Nuovo messaggio a":  			$messaggio = "Neue Mitteilung an"; break;
case "da mostrare dopo le":  			$messaggio = "Anzuzeigen ab"; break;
case "il":  					$messaggio = "den"; break;
case "testo del messaggio":  			$messaggio = "Mitteilungstext"; break;
case "Messaggi":  				$messaggio = "Mitteilungen"; break;
case "Spedisci":  				$messaggio = "Senden"; break;
case "Messaggio inviato":  			$messaggio = "Mitteilung versandt"; break;
case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
case "N°":  					$messaggio = "N"; break;
case "Mittente":  				$messaggio = "Absender"; break;
case "Data":  					$messaggio = "Datum"; break;
case "Azioni":  				$messaggio = "Aktionen"; break;
case "Elimina":  				$messaggio = "L&ouml;schen"; break;
case "Messaggio eliminato":  			$messaggio = "Mitteilung gel&ouml;scht"; break;
case "tutti":  					$messaggio = "jeden"; break;
case "SI":  					$messaggio = "JA"; break;
case "Si è sicuri di voler eliminare la richiesta di prenotazione di":	$messaggio = "Sind Sie sicher, dass Sie die Reservierungsanfrage l&ouml;schen wollen von"; break;
case "non ancora inserita?":  			$messaggio = "noch nicht eingef&uuml;gt?"; break;
case "Inserisci la prenotazione":  		$messaggio = "Reservierung einf&uuml;gen"; break;
case "Visualizza il documento":  		$messaggio = "Dokument anzeigen"; break;
case "di tipo":  				$messaggio = "Typ"; break;
case "Inserito":  				$messaggio = "Eingef&uuml;gt"; break;
case "Elimina tutti i messaggi":  		$messaggio = "Alle Nachrichten l&ouml;schen"; break;
case "Si è sicuri di voler eliminare <div style=\"display: inline; color: red;\"><b>tutti i messaggi</b></div>":                                                 $messaggio = "Sind Sie sicher, dass Sie <div style=\"display: inline; color: red;\"><b>alle Nachrichten l&ouml;schen</b></div> wollen?"; break;
case "Messaggi eliminati":  			$messaggio = "Mitteilungen gel&ouml;scht"; break;
case "arrivati":  				$messaggio = "angekommen"; break;
case "prima del":  				$messaggio = "vor"; break;
case "dopo il":  				$messaggio = "nach"; break;
case "Testo":  					$messaggio = "Text"; break;
case "Scarica messaggi email":  		$messaggio = "Download email messages"; break;
case "Nessun nuovo messaggio":  		$messaggio = "No new message"; break;
case "Nuovi messaggi":  			$messaggio = "New messages"; break;
case "Scaricati":  				$messaggio = "Downloaded"; break;
case "Connessione al server":  			$messaggio = "The connection to server"; break;
case "non riuscita!":  				$messaggio = "was refused!"; break;
case "Controllare i dati immessi in":  		$messaggio = "Check data inserted in"; break;
case "configura e personalizza":  		$messaggio = "configure and customize"; break;
case "Dati ricavati dal messaggio email":  	$messaggio = "Data extracted from email message"; break;
case "Controlla disponibilità":  		$messaggio = "Check availability"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Email":  					$messaggio = "Email"; break;
case "arrivo":  				$messaggio = "arrival"; break;
case "partenza":  				$messaggio = "departure"; break;
case "notti":  					$messaggio = "nights"; break;
case "persone":  				$messaggio = "people"; break;
case "individui":  				$messaggio = "persons"; break;
case "ospiti":  				$messaggio = "guests"; break;
case "adulti":  				$messaggio = "adults"; break;
case "bambini":  				$messaggio = "children"; break;
case "gruppo":  				$messaggio = "party"; break;
case "date":  					$messaggio = "dates"; break;
case "viaggiatori":  				$messaggio = "travelers"; break;
case "periodo":  				$messaggio = "period"; break;
case "Per gli account su gmail potrebbe essere necessario abilitare l'opzione":	$messaggio = "For gmail accounts you may have to enable the option"; break;
case "e/o per una volta usare prima la funzione":	$messaggio = "and/or for once use beforehand the function"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
